@@ -31,7 +31,8 @@ class DLDSDecoder(ABC):
         """
         pass
 
-
+    def __reduce__(self):
+        return (DLDSDecoder, tuple(),)
 #
 # class DefaultDecoder(DLDSDecoder):
 #     def __init__(self) -> None:
@@ -41,4 +42,4 @@ class DLDSDecoder(ABC):
 #         return serialized_file
 #
 #     def get_file_extensions(self) -> List[str]:
-#         return ['all']
\ No newline at end of file
+#         return ['all']
